@@ -31,3 +31,20 @@ class ConfigAlgo(Config):
         help_string="what file systems to check",
     )
 
+
+class ConfigProxy(Config):
+    """
+    Configure proxy settings for the daemon
+    """
+    no_proxy = ParamCreator.create_str_or_none(
+        default="localhost,.amdocs.com,169.254.169.254",
+        help_string="what addresses to exempt from proxy",
+    )
+    http_proxy = ParamCreator.create_str_or_none(
+        default="http://10.65.1.6:8080",
+        help_string="http proxy",
+    )
+    https_proxy = ParamCreator.create_str_or_none(
+        default="http://10.65.1.6:8080",
+        help_string="https proxy",
+    )
